@@ -1,8 +1,10 @@
 from ._session import NullSessionInstance, SessionDictInstance, SessionInstanceBase, SessionManager
+from . import exceptions
 
 __all__ = [
     'SessionManager',
     'SessionDictInstance',
     'SessionInstanceBase',
     'NullSessionInstance',
+    'exceptions',
 ]
